==> vtk6_6.2.0+dfsg1.orig.tar.xz: VTK-6.2.0/IO/Export/vtkRIBLight.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkRIBLight.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkRIBLight - RIP Light
// .SECTION Description
// vtkRIBLight is a subclass of vtkLight that allows the user to
// specify light source shaders and shadow casting lights for use with RenderMan.
//
// .SECTION See Also
// vtkRIBExporter

#ifndef vtkRIBLight_h
#define vtkRIBLight_h

#include "vtkIOExportModule.h" // For export macro
#include "vtkLight.h"

class vtkRIBRenderer;

class VTKIOEXPORT_EXPORT vtkRIBLight : public vtkLight
{
public:
  static vtkRIBLight *New();
  vtkTypeMacro(vtkRIBLight,vtkLight);
  void PrintSelf(ostream& os, vtkIndent indent);

  vtkBooleanMacro(Shadows,int);
  vtkSetMacro(Shadows,int);
  vtkGetMacro(Shadows,int);

  void Render(vtkRenderer *ren, int index);
protected:
  vtkRIBLight();
  ~vtkRIBLight();

  vtkLight *Light;
  int Shadows;
private:
  vtkRIBLight(const vtkRIBLight&);  // Not implemented.
  void operator=(const vtkRIBLight&);  // Not implemented.
};

#endif

==> vtk7_7.1.1+dfsg2.orig.tar.xz: VTK-7.1.1/IO/Export/vtkRIBLight.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkRIBLight.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
/**
 * @class   vtkRIBLight
 * @brief   RIP Light
 *
 * vtkRIBLight is a subclass of vtkLight that allows the user to
 * specify light source shaders and shadow casting lights for use with
 * RenderMan.
 *
 * @sa
 * vtkRIBExporter vtkRIBProperty
*/

#ifndef vtkRIBLight_h
#define vtkRIBLight_h

#include "vtkIOExportModule.h" // For export macro
#include "vtkLight.h"

class vtkRIBRenderer;

class VTKIOEXPORT_EXPORT vtkRIBLight : public vtkLight
{
public:
  static vtkRIBLight *New();
  vtkTypeMacro(vtkRIBLight,vtkLight);
  void PrintSelf(ostream& os, vtkIndent indent);

  vtkBooleanMacro(Shadows,int);
  vtkSetMacro(Shadows,int);
  vtkGetMacro(Shadows,int);

  void Render(vtkRenderer *ren, int index);
protected:
  vtkRIBLight();
  ~vtkRIBLight();

  vtkLight *Light;
  int Shadows;
private:
  vtkRIBLight(const vtkRIBLight&) VTK_DELETE_FUNCTION;
  void operator=(const vtkRIBLight&) VTK_DELETE_FUNCTION;
};

#endif
